mat_discover API
================

Module contents
---------------

.. automodule:: mat_discover
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

mat\_discover.mat\_discover\_ module
------------------------------------

.. automodule:: mat_discover.mat_discover_
   :members:
   :undoc-members:
   :show-inheritance:

mat\_discover.adaptive\_design\_ module
------------------------------------

.. automodule:: mat_discover.adaptive_design
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   mat_discover.utils
